"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.init_mono = void 0;
const execa_1 = __importDefault(require("execa"));
const path_1 = __importDefault(require("path"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const const_1 = require("../../const");
const mkdir_1 = require("../../helpers/mkdir");
const gitignore_1 = require("../../templates/gitignore");
const prettierignore_1 = require("../../templates/prettierignore");
const prettierrc_1 = require("../../templates/prettierrc");
const vsCode_1 = require("../../templates/vsCode");
const initPackage_1 = require("../procedures/initPackage");
async function init_mono(flags) {
    const CWD = process.cwd();
    const execaOptions = {
        stdout: "inherit",
        stderr: "inherit",
    };
    try {
        await initPackage_1.initPackage(CWD);
        await execa_1.default("npm", ["install", "-D", "-E", "husky"], execaOptions);
        await mkdir_1.mkdir(path_1.default.resolve(CWD, "packages"));
    }
    catch (error) {
        console.error(error);
    }
    await vsCode_1.vsCodeSettingsTemplate.render(flags);
    await vsCode_1.vsCodeExtensionsTemplate.render(flags);
    await prettierrc_1.prettierTemplate.render(flags);
    await prettierignore_1.prettierIgnoreTemplate.render(flags);
    await gitignore_1.gitignoreTemplate.render({
        publish_to_git: false,
        listOfModulesWhichLoadOnDemand: const_1.LIST_OF_MODULES_WHICH_LOAD_ON_DEMAND,
        force: flags.force,
    });
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    await rearguardConfig.setType("mono");
    await rearguardConfig.setComponents(["packages"]);
    await rearguardConfig.setScripts({
        bootstrap: "rearguard group bootstrap",
        start: "rearguard group start",
        build: "rearguard group build",
        test: "rearguard group test",
        publish: "rearguard group publish",
        sync: "rearguard group sync",
        validate: "rearguard group validate",
        ["lint-fix"]: "rearguard group lint-fix",
        ["make-prettier"]: "rearguard group make-prettier",
        refresh: "rearguard group refresh",
        clear: "rearguard group clear",
        install: "rearguard group install",
        link: "rearguard group link",
        lint: "rearguard group lint",
        ["validate-prettiness"]: "rearguard group validate-prettiness",
        typecheck: "rearguard group typecheck",
    }, true);
}
exports.init_mono = init_mono;
//# sourceMappingURL=init_mono.js.map